@@ -99,6 +99,8 @@ class Registro(RegistroBase):
 
     @property
     def obter_dados_do_gateway(self):
+        if not self.dados.get("conta_id", None):
+            return False
         return self.topico is not None
 
     @property
